Description Usage Arguments Value See Also
If there is a multi-site model assign rate values to it. Otherwise the rate values are assigned to the single-site model.
1 | ECMMonAssignRateValues(ecmObj, rateValues, unknownRatesWarningQ = TRUE)
|
ecmObj |
An ECMMon object. |
rateValues |
A numerical vector with named elements. The names are expected to be known stocks in the model. |
unknownRatesWarningQ |
Should warnings for unknown to the model rates be issued or not? |
An ECMMon object.
Other Simulation functions:
ECMMonAddRates(),
ECMMonAssignInitialConditions(),
ECMMonBatchSimulate(),
ECMMonExtendByAdjacencyMatrix(),
ECMMonSimulate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.