Description Usage Arguments Details Value See Also
Batch simulates over a data frame of parameters.
1 | ECMMonBatchSimulate(ecmObj, params, maxTime, resultForm = "Simple", ...)
|
ecmObj |
An ECMMon object. |
params |
A data frame of a list of numeric vectors.
If |
maxTime |
A numerical non-negative value for the maximum simulation time. |
resultForm |
A string or NULL. If a string it is expected to be one of "List", "Simple", or "StarSchema". NULL is the same as "Simple". |
... |
Additional parameters of |
If the parameters argument params is a list of numerical vectors
the batch simulation parameters data frame is generated with expand.grid.
An ECMMon object.
Other Simulation functions:
ECMMonAddRates(),
ECMMonAssignInitialConditions(),
ECMMonAssignRateValues(),
ECMMonExtendByAdjacencyMatrix(),
ECMMonSimulate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.