ECMMonExport: Export model and solution into CSV files.

Description Usage Arguments Details Value

View source: R/ECMMon.R

Description

Exports the model elements and solution data frame into CSV files with a specified prefix and in a specified directory.

Usage

1
2
3
4
5
6
ECMMonExport(
  ecmObj,
  directoryName,
  modelID,
  fileNamePrefix = paste0(modelID, "-")
)

Arguments

ecmObj

An ECMMon object.

directoryName

A directory name for the export. If NULL no files are written.

modelID

A string.

fileNamePrefix

A string.

Details

The CSV files are written in the specified directory directoryName. The file name prefix fileNamePrefix is concatenated to the generic file names: "longFormComputationSpecification.csv", "featureMatrix.csv", "timeCellsInterpretation.csv", "featureMatrixTimeSeries.csv". The conversion into long form of the computation specification is considered to be more convenient from a "model management" perspective. The data to be exported is assigned to result's $Value.

Value

An ECMMon object or ECMMonFailureSymbol.


antononcube/ECMMon-R documentation built on April 18, 2021, 10:47 a.m.