ECMMonOption: Optional function application to monad's object.

Description Usage Arguments Details Value

View source: R/ECMMon.R

Description

If monadic failure is obtained from f(ecmObj) then returns the original ecmObj; else returns the result of f(ecmObj).

Usage

1
ECMMonOption(ecmObj, f)

Arguments

ecmObj

An ECMMon object.

f

A function to be applied to the monad object.

Details

In general f should return a monad object, but that is not enforced.

Value

A ECMMon object.


antononcube/ECMMon-R documentation built on April 18, 2021, 10:47 a.m.