ECMMonPlotSolutions: Plot solutions.

Description Usage Arguments Details Value See Also

View source: R/ECMMon.R

Description

Plots solutions.

Usage

1
2
3
4
5
6
7
8
9
ECMMonPlotSolutions(
  ecmObj,
  stocksSpec = NULL,
  maxTime = NULL,
  echoQ = TRUE,
  stockDescriptionsQ = TRUE,
  separatePlotsQ = FALSE,
  ...
)

Arguments

ecmObj

An ECMMon object.

stocksSpec

A character with stock names or string patterns for stock names to be plotted.

maxTime

A numerical non-negative value for the maximum simulation time or NULL. If NULL the maximum time is derived from ecmObj$Solution.

echoQ

Should the plot be echoed or not?

stockDescriptionsQ

Should the stock descriptions be added or not?

separatePlotsQ

Should the stock plots be separated or not?

...

Additional parameters for ggplot2::facet_wrap

Details

The plot is assigned to ecmObj$Value.

Value

An ECMMon object.

See Also

Other Plot functions: ECMMonPlotSolutionHistograms()


antononcube/ECMMon-R documentation built on April 18, 2021, 10:47 a.m.