GetStocks: Get stock symbols.

Description Usage Arguments Value See Also

View source: R/EpidemiologyModelModifications.R

Description

Gets the stock symbols that have descriptions (or names) matching specified patterns.

Usage

1
GetStocks(model, patterns, applyToStockNamesQ = FALSE)

Arguments

model

A model object.

patterns

A a character vector of patterns to be applied to the descriptions of model's stocks.

applyToStockNamesQ

Should the patterns be applied also to the stock names or not?

Value

A character vector

See Also

Other Epidemiology Model Query functions: GetRates()


antononcube/ECMMon-R documentation built on April 18, 2021, 10:47 a.m.