Description Usage Arguments Details Value
Exports the model elements and solution data frame into CSV files with a specified prefix and in a specified directory.
1 2 3 4 5 6 | ECMMonExport(
ecmObj,
directoryName,
modelID,
fileNamePrefix = paste0(modelID, "-")
)
|
ecmObj |
An ECMMon object. |
directoryName |
A directory name for the export. If |
modelID |
A string. |
fileNamePrefix |
A string. |
The CSV files are written in the specified directory directoryName.
The file name prefix fileNamePrefix is concatenated to the generic file names:
"longFormComputationSpecification.csv", "featureMatrix.csv", "timeCellsInterpretation.csv", "featureMatrixTimeSeries.csv".
The conversion into long form of the computation specification is considered to be
more convenient from a "model management" perspective.
The data to be exported is assigned to result's $Value.
An ECMMon object or ECMMonFailureSymbol.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.